spark-stratifier
================

Stratified Cross Validator for Spark

About
-----

Spark Stratifier is a tool with a class extension of the current Spark CrossValidator class. It is aimed to stratify datasets in order to eliminate inconsistent cross validations when working with datasets containing unbalanced classes. It is currently built on numpy and Spark, and provides efficient dataset stratifications.

To learn more, please follow this link to our `Github repo`_.

.. _Github repo: https://github.com/interviewstreet/spark-stratifier
